@@ -4,7 +4,7 @@ from ihm import AsymUnitRange, _remove_identical  # noqa: F401
 import modelcif.data
 import sys
 
-__version__ = '0.7'
+__version__ = '0.8'
 
 
 class System(object):
@@ -224,13 +224,24 @@ class System(object):
                 if isinstance(dg, list):
                     for data in dg:
                         yield data
+
+        def _all_data_in_files():
+            for repo in self.repositories:
+                for f in repo.files:
+                    if f.data:
+                        yield f.data
+                    if hasattr(f, 'files'):
+                        for subf in f.files:
+                            if subf.data:
+                                yield subf.data
         return itertools.chain(
             self.data,
             self.templates,
             self.target_entities,
             self.alignments,
             (model for group, model in self._all_models()),
-            _all_data_in_groups())
+            _all_data_in_groups(),
+            _all_data_in_files())
 
     def _all_data_groups(self):
         """Return all DataGroup (or singleton Data) objects"""
@@ -289,7 +300,7 @@ if sys.version_info[0] >= 3:
     Software.__doc__ = """Software used as part of the modeling protocol.
 
 :param str name: The name of the software.
-:param str classification: The major function of the sofware, for
+:param str classification: The major function of the software, for
        example 'model building', 'sample preparation', 'data collection'.
 :param str description: A longer text description of the software.
 :param str location: Place where the software can be found (e.g. URL).
