@@ -931,6 +931,17 @@ _ma_target_template_poly_mapping.target_seq_id_end
         """Test _AssociatedHandler and _AssociatedArchiveHandler"""
         cif = """
 loop_
+_ma_data.id
+_ma_data.name
+_ma_data.content_type
+_ma_data.content_type_other_details
+42 'Model subunit' target .
+loop_
+_ma_target_entity.entity_id
+_ma_target_entity.data_id
+_ma_target_entity.origin
+1 99 'reference database'
+loop_
 _ma_entry_associated_files.id
 _ma_entry_associated_files.entry_id
 _ma_entry_associated_files.file_url
@@ -938,11 +949,12 @@ _ma_entry_associated_files.file_type
 _ma_entry_associated_files.file_format
 _ma_entry_associated_files.file_content
 _ma_entry_associated_files.details
-1 model https://example.com/foo.txt file other other 'test file'
-2 model https://example.com/t.zip archive zip 'archive with multiple files' .
-3 model baz.txt file other other 'test file3'
-4 model baz.cif file cif other 'test mmCIF'
-5 model baz.bcif file bcif other 'test BinaryCIF'
+_ma_entry_associated_files.data_id
+1 model https://example.com/foo.txt file other other 'test file' .
+2 model https://example.com/t.zip archive zip 'archive with multiple files' . .
+3 model baz.txt file other other 'test file3' .
+4 model baz.cif file cif other 'test mmCIF' .
+5 model baz.bcif file bcif other 'test BinaryCIF' 42
 #
 #
 loop_
@@ -952,10 +964,11 @@ _ma_associated_archive_file_details.file_path
 _ma_associated_archive_file_details.file_format
 _ma_associated_archive_file_details.file_content
 _ma_associated_archive_file_details.description
-1 2 bar.txt other other 'test file2'
-2 99 99.txt other other 'test file99'
-3 2 bar.cif cif other 'test mmCIF in zip'
-4 2 bar.bcif bcif 'local pairwise QA scores' 'test BinaryCIF in zip'
+_ma_associated_archive_file_details.data_id
+1 2 bar.txt other other 'test file2' .
+2 99 99.txt other other 'test file99' .
+3 2 bar.cif cif other 'test mmCIF in zip' .
+4 2 bar.bcif bcif 'local pairwise QA scores' 'test BinaryCIF in zip' 99
 """
         s, = modelcif.reader.read(StringIO(cif))
         r1, r2 = s.repositories
@@ -972,11 +985,13 @@ _ma_associated_archive_file_details.description
         f2, f3, f4 = zf.files
         self.assertEqual(f2.path, 'bar.txt')
         self.assertEqual(f2.details, 'test file2')
+        self.assertIsNone(f2.data)
         self.assertIsInstance(f3, modelcif.associated.CIFFile)
         self.assertFalse(f3.binary)
         self.assertIsInstance(
             f4, modelcif.associated.LocalPairwiseQAScoresFile)
         self.assertTrue(f4.binary)
+        self.assertIsInstance(f4.data, modelcif.Entity)
 
         self.assertIsNone(r2.url_root)
         f3, f4, f5 = r2.files
@@ -984,8 +999,10 @@ _ma_associated_archive_file_details.description
         self.assertEqual(f3.details, 'test file3')
         self.assertIsInstance(f4, modelcif.associated.CIFFile)
         self.assertFalse(f4.binary)
+        self.assertIsNone(f4.data)
         self.assertIsInstance(f5, modelcif.associated.CIFFile)
         self.assertTrue(f5.binary)
+        self.assertEqual(f5.data.__class__, modelcif.data.Data)
 
     def test_template_poly_handler(self):
         """Test _TemplatePolyHandler"""
